<style type="text/css">
pre { overflow: auto; background: silver; border:solid; border-width:thin; padding: 5px  10px; }
dt { font-weight: bold; }
#blog-title a { text-decoration: none; color: black;}
#blog-title span { font-size: 15px; }
td.collapsable { display: none; }
@media only screen and (min-width: 800px) { td.collapsable { display: block; } }
</style>