<div class="title">
 <h1><!-- tmpl_if name='blog_title' -->
     <a href="<!-- tmpl_var name='top' -->"><!-- tmpl_var name='blog_title' --></a>
     <!-- tmpl_else -->
       Untitled Blog
     <!-- /tmpl_if -->
 </h1>
 <!-- tmpl_if name='blog_subtitle' -->
      <h2><!-- tmpl_var name='blog_subtitle' --></h2>
 <!-- /tmpl_if -->
</div>

