
=head1 NAME

App::Chronicle - Holder for our version number

=head1 SYNOPSIS

      use strict;
      use warnings;

      use App::Chronicle;

      print $App::Chronicle::Version;

=cut

=head1 DESCRIPTION

This module is a mere placeholder for our version number.

=cut



package App::Chronicle;

use strict;
use warnings;


our $VERSION = "5.1.7";



1;


=head1 LICENSE

This module is free software; you can redistribute it and/or modify it
under the terms of either:

a) the GNU General Public License as published by the Free Software
Foundation; either version 2, or (at your option) any later version,
or

b) the Perl "Artistic License".

=cut

=head1 AUTHOR

Steve Kemp <steve@steve.org.uk>

=cut
