<div id="footer" style="border-top: 1px solid black;">
<p style="text-align:right;">&copy; 2014 <a href="https://steve.kemp.fi/">Steve Kemp</a> - Built by <a href="<!-- tmpl_var name='chronicle_link' -->">Chronicle</a>, spam filtered by <a href="http://blogspam.net/">BlogSpam.net</a></p>
</div>
